==> rest-sdk-0.1.5-sources.jar: com/mulesoft/connectivity/rest/sdk/internal/validation/ModelValidator.java <==
/*
 * (c) 2003-2021 MuleSoft, Inc. This software is protected under international copyright
 * law. All use of this software is subject to MuleSoft's Master Subscription Agreement
 * (or other master license agreement) separately entered into in writing between you and
 * MuleSoft. If such an agreement is not in place, you may not use the software.
 */
package com.mulesoft.connectivity.rest.sdk.internal.validation;

import static java.util.stream.Collectors.toList;

import com.mulesoft.connectivity.rest.sdk.internal.connectormodel.ConnectorModel;
import com.mulesoft.connectivity.rest.sdk.internal.descriptor.model.ConnectorDescriptor;
import com.mulesoft.connectivity.rest.sdk.internal.validation.rules.AtLeastOneSupportedSecuritySchemeRule;
import com.mulesoft.connectivity.rest.sdk.internal.validation.rules.BaseJavaPackageMustBeValidRule;
import com.mulesoft.connectivity.rest.sdk.internal.validation.rules.ConnectorNameMustBeFriendlyRule;
import com.mulesoft.connectivity.rest.sdk.internal.validation.rules.DescriptorInputMediaTypeMustBePresentInApiRule;
import com.mulesoft.connectivity.rest.sdk.internal.validation.rules.DescriptorOperationMustExistInApiRule;
import com.mulesoft.connectivity.rest.sdk.internal.validation.rules.DescriptorOtputMediaTypeMustBePresentInApiRule;
import com.mulesoft.connectivity.rest.sdk.internal.validation.rules.DescriptorParameterMustBePresentInApiRule;
import com.mulesoft.connectivity.rest.sdk.internal.validation.rules.DescriptorPathMustExistInApiRule;
import com.mulesoft.connectivity.rest.sdk.internal.validation.rules.DescriptorRedundantOutputDefinitionRule;
import com.mulesoft.connectivity.rest.sdk.internal.validation.rules.ExtensionXmlMustBeValidRule;
import com.mulesoft.connectivity.rest.sdk.internal.validation.rules.GavArtifactIdMustBeValidRule;
import com.mulesoft.connectivity.rest.sdk.internal.validation.rules.GavGroupIdMustBeValidRule;
import com.mulesoft.connectivity.rest.sdk.internal.validation.rules.GavVersionMustBeValidRule;
import com.mulesoft.connectivity.rest.sdk.internal.validation.rules.NoDefaultInputMediaTypeDefinedRule;
import com.mulesoft.connectivity.rest.sdk.internal.validation.rules.NoDefaultOutputMediaTypeDefinedRule;
import com.mulesoft.connectivity.rest.sdk.internal.validation.rules.NoInputMediaTypeDefinedRule;
import com.mulesoft.connectivity.rest.sdk.internal.validation.rules.NoOutputMediaTypeDefinedRule;
import com.mulesoft.connectivity.rest.sdk.internal.validation.rules.NotSupportedSecuritySchemeRule;
import com.mulesoft.connectivity.rest.sdk.internal.validation.rules.OperationDisplayNameScriptMustCompileRule;
import com.mulesoft.connectivity.rest.sdk.internal.validation.rules.OperationMustDeclareResponseBodyRule;
import com.mulesoft.connectivity.rest.sdk.internal.validation.rules.OperationNameMustBeFriendlyRule;
import com.mulesoft.connectivity.rest.sdk.internal.validation.rules.PagedOperationsOperationMustDeclareResponseBodyRule;
import com.mulesoft.connectivity.rest.sdk.internal.validation.rules.PagedOperationsParameterMustExistRule;
import com.mulesoft.connectivity.rest.sdk.internal.validation.rules.ParameterNameMustBeFriendlyRule;
import com.mulesoft.connectivity.rest.sdk.internal.validation.rules.SampleDataMarkerMustBeGETRule;
import com.mulesoft.connectivity.rest.sdk.internal.validation.rules.TriggerBindingParameterMustExistInApiRule;
import com.mulesoft.connectivity.rest.sdk.internal.validation.rules.TriggerPathAndMethodMustExistInApiRule;
import com.mulesoft.connectivity.rest.sdk.internal.validation.rules.TriggerUriParamsMustBeCompleteRule;
import com.mulesoft.connectivity.rest.sdk.internal.validation.rules.ValueProviderReferenceArgumentsExistsRule;
import com.mulesoft.connectivity.rest.sdk.internal.validation.rules.ValueProviderReferenceArgumentsHaveValidFormatRule;
import com.mulesoft.connectivity.rest.sdk.internal.webapi.model.APIModel;

import java.util.LinkedList;
import java.util.List;

public class ModelValidator {

  private final List<ValidationRule> validationRules;

  public ModelValidator() {
    this.validationRules = getAllRules();
  }

  public ModelValidator(List<ValidationRule> rules) {
    this.validationRules = rules;
  }

  public List<ValidationError> preValidate(APIModel apiModel, ConnectorDescriptor connectorDescriptor) {
    return validationRules
        .stream()
        .flatMap(x -> x.preValidate(connectorDescriptor, apiModel).stream())
        .collect(toList());
  }

  public List<ValidationError> postValidate(APIModel apiModel, ConnectorDescriptor connectorDescriptor,
                                            ConnectorModel connectorModel) {
    return validationRules
        .stream()
        .flatMap(x -> x.postValidate(connectorDescriptor, apiModel, connectorModel).stream())
        .collect(toList());
  }

  private static List<ValidationRule> getAllRules() {
    final List<ValidationRule> allRules = new LinkedList<>();

    allRules.add(new DescriptorPathMustExistInApiRule());
    allRules.add(new DescriptorOperationMustExistInApiRule());
    allRules.add(new OperationMustDeclareResponseBodyRule());
    allRules.add(new AtLeastOneSupportedSecuritySchemeRule());
    allRules.add(new ExtensionXmlMustBeValidRule());
    allRules.add(new BaseJavaPackageMustBeValidRule());
    allRules.add(new GavGroupIdMustBeValidRule());
    allRules.add(new GavArtifactIdMustBeValidRule());
    allRules.add(new GavVersionMustBeValidRule());
    allRules.add(new NotSupportedSecuritySchemeRule());
    allRules.add(new ConnectorNameMustBeFriendlyRule());
    allRules.add(new OperationNameMustBeFriendlyRule());
    allRules.add(new OperationDisplayNameScriptMustCompileRule());
    allRules.add(new ParameterNameMustBeFriendlyRule());
    allRules.add(new NoDefaultInputMediaTypeDefinedRule());
    allRules.add(new NoDefaultOutputMediaTypeDefinedRule());
    allRules.add(new DescriptorParameterMustBePresentInApiRule());
    allRules.add(new NoInputMediaTypeDefinedRule());
    allRules.add(new DescriptorInputMediaTypeMustBePresentInApiRule());
    allRules.add(new NoOutputMediaTypeDefinedRule());
    allRules.add(new DescriptorOtputMediaTypeMustBePresentInApiRule());
    allRules.add(new DescriptorRedundantOutputDefinitionRule());
    allRules.add(new PagedOperationsOperationMustDeclareResponseBodyRule());
    allRules.add(new TriggerPathAndMethodMustExistInApiRule());
    allRules.add(new TriggerBindingParameterMustExistInApiRule());
    allRules.add(new TriggerUriParamsMustBeCompleteRule());
    allRules.add(new ValueProviderReferenceArgumentsExistsRule());
    allRules.add(new ValueProviderReferenceArgumentsHaveValidFormatRule());
    allRules.add(new SampleDataMarkerMustBeGETRule());
    allRules.add(new PagedOperationsParameterMustExistRule());

    return allRules;
  }
}

==> rest-sdk-0.1.6-sources.jar: com/mulesoft/connectivity/rest/sdk/internal/validation/ModelValidator.java <==
/*
 * (c) 2003-2021 MuleSoft, Inc. This software is protected under international copyright
 * law. All use of this software is subject to MuleSoft's Master Subscription Agreement
 * (or other master license agreement) separately entered into in writing between you and
 * MuleSoft. If such an agreement is not in place, you may not use the software.
 */
package com.mulesoft.connectivity.rest.sdk.internal.validation;

import static java.util.stream.Collectors.toList;

import com.mulesoft.connectivity.rest.sdk.internal.connectormodel.ConnectorModel;
import com.mulesoft.connectivity.rest.sdk.internal.descriptor.model.ConnectorDescriptor;
import com.mulesoft.connectivity.rest.sdk.internal.validation.rules.AtLeastOneSupportedSecuritySchemeRule;
import com.mulesoft.connectivity.rest.sdk.internal.validation.rules.BaseJavaPackageMustBeValidRule;
import com.mulesoft.connectivity.rest.sdk.internal.validation.rules.ConnectorNameMustBeFriendlyRule;
import com.mulesoft.connectivity.rest.sdk.internal.validation.rules.DescriptorAdditionalParameterMandatoryFieldsRule;
import com.mulesoft.connectivity.rest.sdk.internal.validation.rules.DescriptorAdditionalParameterMustNotBePresentInApiRule;
import com.mulesoft.connectivity.rest.sdk.internal.validation.rules.DescriptorInputMediaTypeMustBePresentInApiRule;
import com.mulesoft.connectivity.rest.sdk.internal.validation.rules.DescriptorOperationMustExistInApiRule;
import com.mulesoft.connectivity.rest.sdk.internal.validation.rules.DescriptorOtputMediaTypeMustBePresentInApiRule;
import com.mulesoft.connectivity.rest.sdk.internal.validation.rules.DescriptorParameterMustBePresentInApiRule;
import com.mulesoft.connectivity.rest.sdk.internal.validation.rules.DescriptorPathMustExistInApiRule;
import com.mulesoft.connectivity.rest.sdk.internal.validation.rules.DescriptorRedundantOutputDefinitionRule;
import com.mulesoft.connectivity.rest.sdk.internal.validation.rules.ExtensionXmlMustBeValidRule;
import com.mulesoft.connectivity.rest.sdk.internal.validation.rules.GavArtifactIdMustBeValidRule;
import com.mulesoft.connectivity.rest.sdk.internal.validation.rules.GavGroupIdMustBeValidRule;
import com.mulesoft.connectivity.rest.sdk.internal.validation.rules.GavVersionMustBeValidRule;
import com.mulesoft.connectivity.rest.sdk.internal.validation.rules.NoDefaultInputMediaTypeDefinedRule;
import com.mulesoft.connectivity.rest.sdk.internal.validation.rules.NoDefaultOutputMediaTypeDefinedRule;
import com.mulesoft.connectivity.rest.sdk.internal.validation.rules.NoInputMediaTypeDefinedRule;
import com.mulesoft.connectivity.rest.sdk.internal.validation.rules.NoOutputMediaTypeDefinedRule;
import com.mulesoft.connectivity.rest.sdk.internal.validation.rules.NotSupportedSecuritySchemeRule;
import com.mulesoft.connectivity.rest.sdk.internal.validation.rules.OperationDisplayNameScriptMustCompileRule;
import com.mulesoft.connectivity.rest.sdk.internal.validation.rules.OperationIdentifierScriptMustCompileRule;
import com.mulesoft.connectivity.rest.sdk.internal.validation.rules.OperationIdentifierScriptMustNotRepeatRule;
import com.mulesoft.connectivity.rest.sdk.internal.validation.rules.OperationMustDeclareResponseBodyRule;
import com.mulesoft.connectivity.rest.sdk.internal.validation.rules.OperationNameMustBeFriendlyRule;
import com.mulesoft.connectivity.rest.sdk.internal.validation.rules.PagedOperationsExpressionMustCompileRule;
import com.mulesoft.connectivity.rest.sdk.internal.validation.rules.PagedOperationsOperationMustDeclareResponseBodyRule;
import com.mulesoft.connectivity.rest.sdk.internal.validation.rules.PagedOperationsParameterMustExistRule;
import com.mulesoft.connectivity.rest.sdk.internal.validation.rules.SampleDataMarkerMustBeGETRule;
import com.mulesoft.connectivity.rest.sdk.internal.validation.rules.TriggerBindingParameterMustExistInApiRule;
import com.mulesoft.connectivity.rest.sdk.internal.validation.rules.TriggerPathAndMethodMustExistInApiRule;
import com.mulesoft.connectivity.rest.sdk.internal.validation.rules.TriggerUriParamsMustBeCompleteRule;
import com.mulesoft.connectivity.rest.sdk.internal.validation.rules.ValueProviderReferenceArgumentsExistsRule;
import com.mulesoft.connectivity.rest.sdk.internal.validation.rules.ValueProviderReferenceArgumentsHaveValidFormatRule;
import com.mulesoft.connectivity.rest.sdk.internal.webapi.model.APIModel;

import java.util.LinkedList;
import java.util.List;

public class ModelValidator {

  private final List<ValidationRule> validationRules;

  public ModelValidator() {
    this.validationRules = getAllRules();
  }

  public ModelValidator(List<ValidationRule> rules) {
    this.validationRules = rules;
  }

  public List<ValidationError> preValidate(APIModel apiModel, ConnectorDescriptor connectorDescriptor) {
    return validationRules
        .stream()
        .flatMap(x -> x.preValidate(connectorDescriptor, apiModel).stream())
        .collect(toList());
  }

  public List<ValidationError> postValidate(APIModel apiModel, ConnectorDescriptor connectorDescriptor,
                                            ConnectorModel connectorModel) {
    return validationRules
        .stream()
        .flatMap(x -> x.postValidate(connectorDescriptor, apiModel, connectorModel).stream())
        .collect(toList());
  }

  private static List<ValidationRule> getAllRules() {
    final List<ValidationRule> allRules = new LinkedList<>();

    allRules.add(new DescriptorPathMustExistInApiRule());
    allRules.add(new DescriptorOperationMustExistInApiRule());
    allRules.add(new OperationMustDeclareResponseBodyRule());
    allRules.add(new AtLeastOneSupportedSecuritySchemeRule());
    allRules.add(new ExtensionXmlMustBeValidRule());
    allRules.add(new BaseJavaPackageMustBeValidRule());
    allRules.add(new GavGroupIdMustBeValidRule());
    allRules.add(new GavArtifactIdMustBeValidRule());
    allRules.add(new GavVersionMustBeValidRule());
    allRules.add(new NotSupportedSecuritySchemeRule());
    allRules.add(new ConnectorNameMustBeFriendlyRule());
    allRules.add(new OperationNameMustBeFriendlyRule());
    allRules.add(new OperationDisplayNameScriptMustCompileRule());
    allRules.add(new OperationIdentifierScriptMustCompileRule());
    allRules.add(new OperationIdentifierScriptMustNotRepeatRule());
    allRules.add(new NoDefaultInputMediaTypeDefinedRule());
    allRules.add(new NoDefaultOutputMediaTypeDefinedRule());
    allRules.add(new DescriptorParameterMustBePresentInApiRule());
    allRules.add(new NoInputMediaTypeDefinedRule());
    allRules.add(new DescriptorInputMediaTypeMustBePresentInApiRule());
    allRules.add(new NoOutputMediaTypeDefinedRule());
    allRules.add(new DescriptorOtputMediaTypeMustBePresentInApiRule());
    allRules.add(new DescriptorRedundantOutputDefinitionRule());
    allRules.add(new PagedOperationsOperationMustDeclareResponseBodyRule());
    allRules.add(new TriggerPathAndMethodMustExistInApiRule());
    allRules.add(new TriggerBindingParameterMustExistInApiRule());
    allRules.add(new TriggerUriParamsMustBeCompleteRule());
    allRules.add(new ValueProviderReferenceArgumentsExistsRule());
    allRules.add(new ValueProviderReferenceArgumentsHaveValidFormatRule());
    allRules.add(new SampleDataMarkerMustBeGETRule());
    allRules.add(new PagedOperationsParameterMustExistRule());
    allRules.add(new PagedOperationsExpressionMustCompileRule());
    allRules.add(new DescriptorAdditionalParameterMandatoryFieldsRule());
    allRules.add(new DescriptorAdditionalParameterMustNotBePresentInApiRule());

    return allRules;
  }
}
